==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/bg_BG.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Address book name" : "Име на адреснакнига ",
    "Import" : "Внасяне",
    "No contacts in here" : "Тук няма контакти",
    "Name" : "Име",
    "Organization" : "Организация",
    "Title" : "Заглавие",
    "Add field ..." : "Добави приятел",
    "No search result for {query}" : "Няма намерени резултати за {query}",
    "Postal code" : "Пощенски код",
    "City" : "Град",
    "State or province" : "Страна или област",
    "Country" : "Държава",
    "Address" : "Адрес",
    "(new group)" : "(нова група)",
    "Last name" : "Последно име",
    "First name" : "Първо Име",
    "Additional names" : "Други имена",
    "All contacts" : "Всички контакти",
    "Not grouped" : "Негрупирани",
    "New contact" : "Нов контакт",
    "{addressbook} shared by {owner}" : "{addressbook} споделена с {owner}",
    "No contacts in file. Only VCard files are allowed." : "Няма контакти в файла. Само VCard файлове са разрешени.",
    "Nickname" : "Псевдоним",
    "Notes" : "Бележки",
    "Website" : "Интернет Страница",
    "Home" : "Домашен",
    "Work" : "Работно",
    "Other" : "Друга...",
    "Groups" : "Групи",
    "Birthday" : "Рожден ден",
    "Email" : "Имейл",
    "Instant messaging" : "Чат",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Fax" : "Факс",
    "Fax home" : "Факс домашен",
    "Fax work" : "Факс служебен",
    "Pager" : "Пейджър",
    "Voice" : "Гласов",
    "Settings" : "Настройки"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/bg_BG.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Изтегляне",
    "Share with users or groups" : "Споделяне с потребители или групи",
    "Delete" : "Изтриване",
    "can edit" : "може да променя",
    "Address book name" : "Име на адреснакнига ",
    "Import" : "Внасяне",
    "The selected image is too big (max 1MB)" : "Избраното изображение е твърде голямо (най-много 1МБ)",
    "No contacts in here" : "Тук няма контакти",
    "Name" : "Име",
    "Organization" : "Организация",
    "Title" : "Заглавие",
    "Add field ..." : "Добави приятел",
    "No search result for {query}" : "Няма намерени резултати за {query}",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакта"],
    "Post office box" : "Офисна пощенска кутия",
    "Postal code" : "Пощенски код",
    "City" : "Град",
    "State or province" : "Страна или област",
    "Country" : "Държава",
    "Address" : "Адрес",
    "(new group)" : "(нова група)",
    "Last name" : "Последно име",
    "First name" : "Първо Име",
    "Additional names" : "Други имена",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "All contacts" : "Всички контакти",
    "Not grouped" : "Негрупирани",
    "New contact" : "Нов контакт",
    "{addressbook} shared by {owner}" : "{addressbook} споделена с {owner}",
    "Contact could not be created." : "Контактът не може да бъде създаден.",
    "No contacts in file. Only VCard files are allowed." : "Няма контакти в файла. Само VCard файлове са разрешени.",
    "Nickname" : "Псевдоним",
    "Detailed name" : "Подробно име",
    "Notes" : "Бележки",
    "Website" : "Интернет Страница",
    "Federated Cloud ID" : "Федерирано Cloud ID",
    "Home" : "Домашен",
    "Work" : "Работно",
    "Other" : "Друга...",
    "Groups" : "Групи",
    "Birthday" : "Рожден ден",
    "Anniversary" : "Годишнина",
    "Date of death" : "Дата на смъртта",
    "Email" : "Имейл",
    "Instant messaging" : "Чат",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Fax" : "Факс",
    "Fax home" : "Факс домашен",
    "Fax work" : "Факс служебен",
    "Pager" : "Пейджър",
    "Voice" : "Гласов",
    "Social network" : "Социална мрежа",
    "Settings" : "Настройки"
},
"nplurals=2; plural=(n != 1);");
